/*
 * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "otbTestMain.h"

void RegisterTests()
{
  REGISTER_TEST(otbGDALImageIOTest_uint8);
  REGISTER_TEST(otbGDALImageIOTest_uint16);
  REGISTER_TEST(otbGDALImageIOTestWriteMetadata);
  REGISTER_TEST(otbGDALOverviewsBuilder);
  REGISTER_TEST(otbGDALImageIOTestCanWrite);
  REGISTER_TEST(otbOGRVectorDataIOCanWrite);
  REGISTER_TEST(otbGDALReadPxlComplexFloat);
  REGISTER_TEST(otbGDALReadPxlComplexDouble);
  REGISTER_TEST(otbGDALImageIOTestCanRead);
  REGISTER_TEST(otbMultiDatasetReadingInfo);
  REGISTER_TEST(otbOGRVectorDataIOTestCanRead);
  REGISTER_TEST(otbDEMHandlerTest);
  REGISTER_TEST(otbGDALRPCTransformerTest);
  REGISTER_TEST(otbGDALRPCTransformerTest2);
}
